@@ -11,6 +11,7 @@
 # under the License.
 
 from openstack.network.v2 import address_scope as _address_scope
+from openstack.network.v2 import agent as _agent
 from openstack.network.v2 import availability_zone
 from openstack.network.v2 import extension
 from openstack.network.v2 import floating_ip as _floating_ip
@@ -20,13 +21,16 @@ from openstack.network.v2 import load_balancer as _load_balancer
 from openstack.network.v2 import metering_label as _metering_label
 from openstack.network.v2 import metering_label_rule as _metering_label_rule
 from openstack.network.v2 import network as _network
+from openstack.network.v2 import network_ip_availability
 from openstack.network.v2 import pool as _pool
 from openstack.network.v2 import pool_member as _pool_member
 from openstack.network.v2 import port as _port
 from openstack.network.v2 import quota as _quota
+from openstack.network.v2 import rbac_policy as _rbac_policy
 from openstack.network.v2 import router as _router
 from openstack.network.v2 import security_group as _security_group
 from openstack.network.v2 import security_group_rule as _security_group_rule
+from openstack.network.v2 import segment as _segment
 from openstack.network.v2 import subnet as _subnet
 from openstack.network.v2 import subnet_pool as _subnet_pool
 from openstack.network.v2 import vpn_service as _vpn_service
@@ -121,6 +125,59 @@ class Proxy(proxy.BaseProxy):
                             address_scope,
                             **attrs)
 
+    def agents(self, **query):
+        """Return a generator of network agents
+
+        :param kwargs \*\*query: Optional query parameters to be sent to limit
+                                 the resources being returned.
+
+        :returns: A generator of agents
+        :rtype: :class:`~openstack.network.v2.agent.Agent`
+        """
+        return self._list(_agent.Agent, paginated=False, **query)
+
+    def delete_agent(self, agent, ignore_missing=True):
+        """Delete a network agent
+
+        :param agent: The value can be the ID of a agent or a
+                     :class:`~openstack.network.v2.agent.Agent` instance.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the agent does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent agent.
+
+        :returns: ``None``
+        """
+        self._delete(_agent.Agent, agent,
+                     ignore_missing=ignore_missing)
+
+    def get_agent(self, agent, ignore_missing=True):
+        """Get a single network agent
+
+        :param agent: The value can be the ID of a agent or a
+                     :class:`~openstack.network.v2.agent.Agent` instance.
+
+        :returns: One :class:`~openstack.network.v2.agent.Agent`
+        :rtype: :class:`~openstack.network.v2.agent.Agent`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        return self._get(_agent.Agent, agent)
+
+    def update_agent(self, agent, **attrs):
+        """Update a network agent
+
+        :param agent: The value can be the ID of a agent or a
+                     :class:`~openstack.network.v2.agent.Agent` instance.
+        :attrs kwargs: The attributes to update on the agent represented
+                       by ``value``.
+
+        :returns: One :class:`~openstack.network.v2.agent.Agent`
+        :rtype: :class:`~openstack.network.v2.agent.Agent`
+        """
+        return self._update(_agent.Agent, agent, **attrs)
+
     def availability_zones(self):
         """Return a generator of availability zones
 
@@ -757,6 +814,50 @@ class Proxy(proxy.BaseProxy):
         """
         return self._update(_network.Network, network, **attrs)
 
+    def find_network_ip_availability(self, name_or_id, ignore_missing=True):
+        """Find IP availability of a network
+
+        :param name_or_id: The name or ID of a network.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the resource does not exist.
+                    When set to ``True``, None will be returned when
+                    attempting to find a nonexistent resource.
+        :returns: One :class:`~openstack.network.v2.network_ip_availability.
+                       NetworkIPAvailability` or None
+        """
+        return self._find(network_ip_availability.NetworkIPAvailability,
+                          name_or_id,
+                          ignore_missing=ignore_missing)
+
+    def get_network_ip_availability(self, network):
+        """Get IP availability of a network
+
+        :param network:
+            The value can be the ID of a network or a
+            :class:`~openstack.network.v2.network.Network` instance.
+
+        :returns: One :class:`~openstack.network.v2.network_ip_availability.
+                      NetworkIPAvailability`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        return self._get(network_ip_availability.NetworkIPAvailability,
+                         network)
+
+    def network_ip_availabilities(self, **query):
+        """Return a generator of network ip availabilities
+
+        :param kwargs \*\*query: Optional query parameters to be sent to limit
+                                 the resources being returned.
+
+        :returns: A generator of network ip availability objects
+        :rtype: :class:`~openstack.network.v2.network_ip_availability.
+                NetworkIPAvailability`
+        """
+        return self._list(network_ip_availability.NetworkIPAvailability,
+                          paginated=False, **query)
+
     def create_pool(self, **attrs):
         """Create a new pool from attributes
 
@@ -1099,6 +1200,91 @@ class Proxy(proxy.BaseProxy):
         """
         return self._update(_quota.Quota, quota, **attrs)
 
+    def create_rbac_policy(self, **attrs):
+        """Create a new RBAC policy from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create a
+            :class:`~openstack.network.v2.rbac_policy.RBACPolicy`,
+            comprised of the properties on the RBACPolicy class.
+
+        :return: The results of RBAC policy creation
+        :rtype: :class:`~openstack.network.v2.rbac_policy.RBACPolicy`
+        """
+        return self._create(_rbac_policy.RBACPolicy, **attrs)
+
+    def delete_rbac_policy(self, rbac_policy, ignore_missing=True):
+        """Delete a RBAC policy
+
+        :param rbac_policy: The value can be either the ID of a RBAC policy or
+            a :class:`~openstack.network.v2.rbac_policy.RBACPolicy` instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the RBAC policy does not exist.
+            When set to ``True``, no exception will be set when
+            attempting to delete a nonexistent RBAC policy.
+
+        :returns: ``None``
+        """
+        self._delete(_rbac_policy.RBACPolicy, rbac_policy,
+                     ignore_missing=ignore_missing)
+
+    def find_rbac_policy(self, id, ignore_missing=True):
+        """Find a single RBAC policy
+
+        :param id: The ID of a RBAC policy.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the resource does not exist.
+            When set to ``True``, None will be returned when
+            attempting to find a nonexistent resource.
+        :returns: One
+            :class:`~openstack.network.v2.rbac_policy.RBACPolicy` or None
+        """
+        return self._find(_rbac_policy.RBACPolicy, id,
+                          ignore_missing=ignore_missing)
+
+    def get_rbac_policy(self, rbac_policy):
+        """Get a single RBAC policy
+
+        :param rbac_policy: The value can be the ID of a RBAC policy or a
+            :class:`~openstack.network.v2.rbac_policy.RBACPolicy` instance.
+
+        :returns: One :class:`~openstack.network.v2.rbac_policy.RBACPolicy`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+            when no resource can be found.
+        """
+        return self._get(_rbac_policy.RBACPolicy, rbac_policy)
+
+    def rbac_policies(self, **query):
+        """Return a generator of RBAC policies
+
+        :param kwargs \*\*query: Optional query parameters to be sent to limit
+            the resources being returned. Available parameters include:
+
+            * tenant_id: The owner tenant ID.
+            * target_tenant: ID of the tenant to which the RBAC policy
+                will be enforced.
+            * object_type: Type of the object that RBAC policy affects.
+            * action: Action for the RBAC policy.
+
+        :returns: A generator of rbac objects
+        :rtype: :class:`~openstack.network.v2.rbac_policy.RBACPolicy`
+        """
+        return self._list(_rbac_policy.RBACPolicy, paginated=False, **query)
+
+    def update_rbac_policy(self, rbac_policy, **attrs):
+        """Update a RBAC policy
+
+        :param rbac_policy: Either the id of a RBAC policy or a
+            :class:`~openstack.network.v2.rbac_policy.RBACPolicy` instance.
+        :attrs kwargs: The attributes to update on the RBAC policy represented
+            by ``value``.
+
+        :returns: The updated RBAC policy
+        :rtype: :class:`~openstack.network.v2.rbac_policy.RBACPolicy`
+        """
+        return self._update(_rbac_policy.RBACPolicy, rbac_policy, **attrs)
+
     def create_router(self, **attrs):
         """Create a new router from attributes
 
@@ -1399,6 +1585,58 @@ class Proxy(proxy.BaseProxy):
         return self._list(_security_group_rule.SecurityGroupRule,
                           paginated=False, **query)
 
+    def find_segment(self, name_or_id, ignore_missing=True):
+        """Find a single segment
+
+        .. caution::
+           BETA: This API is a work in progress and is subject to change.
+
+        :param name_or_id: The name or ID of a segment.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the resource does not exist.
+                    When set to ``True``, None will be returned when
+                    attempting to find a nonexistent resource.
+        :returns: One :class:`~openstack.network.v2.segment.Segment` or None
+        """
+        return self._find(_segment.Segment, name_or_id,
+                          ignore_missing=ignore_missing)
+
+    def get_segment(self, segment):
+        """Get a single segment
+
+        .. caution::
+           BETA: This API is a work in progress and is subject to change.
+
+        :param segment: The value can be the ID of a segment or a
+                        :class:`~openstack.network.v2.segment.Segment`
+                        instance.
+
+        :returns: One :class:`~openstack.network.v2.segment.Segment`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        return self._get(_segment.Segment, segment)
+
+    def segments(self, **query):
+        """Return a generator of segments
+
+        .. caution::
+           BETA: This API is a work in progress and is subject to change.
+
+        :param kwargs \*\*query: Optional query parameters to be sent to limit
+            the resources being returned. Available parameters include:
+
+            * network_id: ID of the network that owns the segments
+            * network_type: Network type for the segments
+            * physical_network: Physical network name for the segments
+            * segmentation_id: Segmentation ID for the segments
+
+        :returns: A generator of segment objects
+        :rtype: :class:`~openstack.network.v2.segment.Segment`
+        """
+        return self._list(_segment.Segment, paginated=False, **query)
+
     def create_subnet(self, **attrs):
         """Create a new subnet from attributes
 
