@@ -32,6 +32,10 @@ class Subnet(resource.Resource):
     allocation_pools = resource.prop('allocation_pools')
     #: The CIDR.
     cidr = resource.prop('cidr')
+    #: Timestamp when the subnet was created.
+    created_at = resource.prop('created_at')
+    #: The subnet description.
+    description = resource.prop('description')
     #: A list of DNS nameservers.
     dns_nameservers = resource.prop('dns_nameservers')
     #: The gateway IP address.
@@ -54,5 +58,9 @@ class Subnet(resource.Resource):
     network_id = resource.prop('network_id')
     #: The ID of the project this subnet is associated with.
     project_id = resource.prop('tenant_id')
+    #: The ID of the segment this subnet is associated with.
+    segment_id = resource.prop('segment_id')
     #: The subnet pool ID from which to obtain a CIDR.
     subnet_pool_id = resource.prop('subnetpool_id')
+    #: Timestamp when the subnet was last updated.
+    updated_at = resource.prop('updated_at')
